==> 1.0.4.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/JsDefaultCallback.java <==
package net.xinhuamm.xycloud.xinhuamm_xycloud;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import com.google.gson.Gson;
import java.util.Collection;
import java.util.Iterator;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class JsDefaultCallback {
    @NonNull
    private JSONObject jsonObject;

    public JsDefaultCallback(@NonNull JSONObject jsonObject) {
        this.jsonObject = jsonObject;

        try {
            jsonObject.put("actionName", jsonObject.optString("callbackActionName"));
            jsonObject.remove("parameters");
        } catch (JSONException var3) {
            var3.printStackTrace();
        }

    }

    @Nullable
    public String getCallbackJsAction(Object parameters) {
        try {
            if (!(parameters instanceof String) && !(parameters instanceof JSONObject)) {
                if (parameters instanceof Collection) {
                    Collection<?> collection = (Collection)parameters;
                    JSONArray array = new JSONArray();
                    Gson gson = new Gson();
                    Iterator var5 = collection.iterator();

                    while(var5.hasNext()) {
                        Object obj = var5.next();
                        array.put(new JSONObject(gson.toJson(obj)));
                    }

                    this.jsonObject.put("parameters", array);
                } else {
                    JSONObject params = new JSONObject((new Gson()).toJson(parameters));
                    this.jsonObject.put("parameters", params);
                }
            } else {
                this.jsonObject.put("parameters", parameters);
            }

            return String.format("javascript:window.%s.nativeCallJS(%s)", "webJSBridge", this.jsonObject);
        } catch (JSONException var7) {
            var7.printStackTrace();
            return null;
        }
    }
}

==> 1.1.5.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/JsDefaultCallback.java <==
package net.xinhuamm.xycloud.xinhuamm_xycloud;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import com.google.gson.Gson;
import com.xinhuamm.client.bridge.O2OJsInterface;

import java.util.Collection;
import java.util.Iterator;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class JsDefaultCallback {
    @NonNull
    private JSONObject jsonObject;

    public JsDefaultCallback(@NonNull JSONObject jsonObject) {
        this.jsonObject = jsonObject;

        try {
            jsonObject.put("actionName", jsonObject.optString("callbackActionName"));
            jsonObject.remove("parameters");
        } catch (JSONException var3) {
            var3.printStackTrace();
        }

    }

    @Nullable
    public String getCallbackJsAction(Object parameters) {
        try {
            if (!(parameters instanceof String) && !(parameters instanceof JSONObject)) {
                if (parameters instanceof Collection) {
                    Collection<?> collection = (Collection)parameters;
                    JSONArray array = new JSONArray();
                    Gson gson = new Gson();
                    Iterator var5 = collection.iterator();

                    while(var5.hasNext()) {
                        Object obj = var5.next();
                        array.put(new JSONObject(gson.toJson(obj)));
                    }

                    this.jsonObject.put("parameters", array);
                } else {
                    JSONObject params = new JSONObject((new Gson()).toJson(parameters));
                    this.jsonObject.put("parameters", params);
                }
            } else {
                this.jsonObject.put("parameters", parameters);
            }

            return String.format("javascript:window.%s.nativeCallJS(%s)", O2OJsInterface.JS_INTERFACE_WEB, this.jsonObject);
        } catch (JSONException var7) {
            var7.printStackTrace();
            return null;
        }
    }
}
